package com.bonus.canteen.core.health.mapper;

import java.util.List;
import com.bonus.canteen.core.health.domain.HealthPersonMedicalReportProject;

/**
 * 人员体检报告项目Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface HealthPersonMedicalReportProjectMapper {
    /**
     * 查询人员体检报告项目
     * 
     * @param id 人员体检报告项目主键
     * @return 人员体检报告项目
     */
    public HealthPersonMedicalReportProject selectHealthPersonMedicalReportProjectById(Long id);

    /**
     * 查询人员体检报告项目列表
     * 
     * @param healthPersonMedicalReportProject 人员体检报告项目
     * @return 人员体检报告项目集合
     */
    public List<HealthPersonMedicalReportProject> selectHealthPersonMedicalReportProjectList(HealthPersonMedicalReportProject healthPersonMedicalReportProject);

    /**
     * 新增人员体检报告项目
     * 
     * @param healthPersonMedicalReportProject 人员体检报告项目
     * @return 结果
     */
    public int insertHealthPersonMedicalReportProject(HealthPersonMedicalReportProject healthPersonMedicalReportProject);

    /**
     * 修改人员体检报告项目
     * 
     * @param healthPersonMedicalReportProject 人员体检报告项目
     * @return 结果
     */
    public int updateHealthPersonMedicalReportProject(HealthPersonMedicalReportProject healthPersonMedicalReportProject);

    /**
     * 删除人员体检报告项目
     * 
     * @param id 人员体检报告项目主键
     * @return 结果
     */
    public int deleteHealthPersonMedicalReportProjectById(Long id);

    /**
     * 批量删除人员体检报告项目
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHealthPersonMedicalReportProjectByIds(Long[] ids);
}
