package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthPersonMedicalReportProject;
import com.bonus.canteen.core.health.service.IHealthPersonMedicalReportProjectService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 人员体检报告项目Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "人员体检报告项目接口")
@RestController
@RequestMapping("/health_person_medical_report_project")
public class HealthPersonMedicalReportProjectController extends BaseController {
    @Autowired
    private IHealthPersonMedicalReportProjectService healthPersonMedicalReportProjectService;

    /**
     * 查询人员体检报告项目列表
     */
    @ApiOperation(value = "查询人员体检报告项目列表")
    //@RequiresPermissions("health:project:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthPersonMedicalReportProject healthPersonMedicalReportProject) {
        startPage();
        List<HealthPersonMedicalReportProject> list = healthPersonMedicalReportProjectService.selectHealthPersonMedicalReportProjectList(healthPersonMedicalReportProject);
        return getDataTable(list);
    }

    /**
     * 导出人员体检报告项目列表
     */
    @ApiOperation(value = "导出人员体检报告项目列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:project:export")
    @SysLog(title = "人员体检报告项目", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出人员体检报告项目")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthPersonMedicalReportProject healthPersonMedicalReportProject) {
        List<HealthPersonMedicalReportProject> list = healthPersonMedicalReportProjectService.selectHealthPersonMedicalReportProjectList(healthPersonMedicalReportProject);
        ExcelUtil<HealthPersonMedicalReportProject> util = new ExcelUtil<HealthPersonMedicalReportProject>(HealthPersonMedicalReportProject.class);
        util.exportExcel(response, list, "人员体检报告项目数据");
    }

    /**
     * 获取人员体检报告项目详细信息
     */
    @ApiOperation(value = "获取人员体检报告项目详细信息")
    //@RequiresPermissions("health:project:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthPersonMedicalReportProjectService.selectHealthPersonMedicalReportProjectById(id));
    }

    /**
     * 新增人员体检报告项目
     */
    @ApiOperation(value = "新增人员体检报告项目")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:project:add")
    @SysLog(title = "人员体检报告项目", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增人员体检报告项目")
    @PostMapping
    public AjaxResult add(@RequestBody HealthPersonMedicalReportProject healthPersonMedicalReportProject) {
        try {
            return toAjax(healthPersonMedicalReportProjectService.insertHealthPersonMedicalReportProject(healthPersonMedicalReportProject));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改人员体检报告项目
     */
    @ApiOperation(value = "修改人员体检报告项目")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:project:edit")
    @SysLog(title = "人员体检报告项目", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改人员体检报告项目")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthPersonMedicalReportProject healthPersonMedicalReportProject) {
        try {
            return toAjax(healthPersonMedicalReportProjectService.updateHealthPersonMedicalReportProject(healthPersonMedicalReportProject));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除人员体检报告项目
     */
    @ApiOperation(value = "删除人员体检报告项目")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:project:remove")
    @SysLog(title = "人员体检报告项目", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除人员体检报告项目")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthPersonMedicalReportProjectService.deleteHealthPersonMedicalReportProjectByIds(ids));
    }
}
